@@ -16,11 +16,12 @@ def edit_today(journal_path):
         entry_path = pathlib.Path(f"{journal_path}/entries/{today.year}/0{today.month}")
 
     entry_path.mkdir(parents=True, exist_ok=True)
+    entry_path = entry_path / f"{today.day}.tex"
 
     if not entry_path.is_file():
-        create_entry(f"{entry_path}/{today.day}.tex")
+        create_entry(entry_path)
 
-    subprocess.call([EDITOR, entry_path/f"{today.day}.tex"])
+    subprocess.call([EDITOR, entry_path])
 
 
 def create_entry(entry_path):
